@@ -1,13 +1,14 @@
 """Module containing helper functions for testing PyTeal Utils."""
 from typing import Any
 from algosdk.atomic_transaction_composer import AtomicTransactionComposer
+from algosdk.v2client.algod import AlgodClient
 
 import pyteal as pt
 from beaker import client, sandbox
 from beaker import Application, external, delete, update, opt_in, close_out
 
-algod_client = None
-sandbox_accounts = None
+algod_client: AlgodClient | None = None
+sandbox_accounts: list[sandbox.SandboxAccount] | None = None
 
 
 def returned_int_as_bytes(i: int, bits: int = 64):
@@ -22,14 +23,17 @@ class UnitTestingApp(Application):
 
 
     1) Initialize with a single Expr that returns bytes
-        The bytes output from the Expr are returned from the abi method ``unit_test()[]byte``
+        The bytes output from the Expr are returned from
+        the abi method ``unit_test()[]byte``
 
     2) Subclass UnitTestingApp and override `unit_test`
-        Any inputs or output may be specified but you're responsible for encoding the incoming
-        arguments as a dict with keys matching the argument names of the custom `unit_test` method
+        Any inputs or output may be specified but you're
+        responsible for encoding the incoming arguments as a
+        dict with keys matching the argument names of the custom `unit_test` method
 
 
-    An instance of this class is passed to assert_output to check the return value against what you expect.
+    An instance of this class is passed to assert_output to check
+    the return value against what you expect.
     """
 
     def __init__(self, expr_to_test: pt.Expr | None = None):
@@ -60,7 +64,8 @@ class UnitTestingApp(Application):
     def unit_test(self, *, output: pt.abi.DynamicArray[pt.abi.Byte]):
         if self.expr is None:
             raise Exception(
-                "Expression undefined. Either set the expr to test on init or override unit_test method"
+                "Expression undefined. Either set the expr to "
+                + "test on init or override unit_test method"
             )
         return pt.Seq((s := pt.abi.String()).set(self.expr), output.decode(s.encode()))
 
@@ -72,12 +77,18 @@ def assert_output(
     opups: int = 0,
 ):
     """
-    Creates and calls the UnitTestingApp passed and compares the return value with the expected output
+    Creates and calls the UnitTestingApp passed and compares the
+    return value with the expected output
 
-    :param app: An instance of a UnitTestingApp to make call against its `unit_test` method
-    :param inputs: A list of dicts where each entry contains keys matching the input args for the `unit_test` method  and values corresponding to the type expected by the method
-    :param outputs: A list of outputs to compare against the return value of the output of the `unit_test` method
-    :param opups: A number of additional app call transactions to make to increase our budget
+    :param app: An instance of a UnitTestingApp to make call
+        against its `unit_test` method
+    :param inputs: A list of dicts where each entry contains keys
+        matching the input args for the `unit_test` method  and values
+        corresponding to the type expected by the method
+    :param outputs: A list of outputs to compare against the return
+        value of the output of the `unit_test` method
+    :param opups: A number of additional app call transactions to
+        make to increase our budget
 
     """
     # TODO: make these avail in a pytest session context? pass them in directly?
